

# 1.0.3

* Add mdn to init

# 1.0.2

* Remove tanh activation from variational layer
* Add librispeech train code to fastwavenet module
* Add Mixture Density Network code from course in mdn module

# 1.0.1

Fixed model loading during charrnn infer method.  No longer checks for ckpt name and will attempt to load regardless.

# 1.0.0

Initial release
